title: Territorialiser les systèmes numériques, l’exemple des centres de données
url: https://gauthierroussilhe.com/post/territoires-centres-de-donnees.html
hash_url: 618145b6b22de36fbbc1cd3162d41515

<p>
    Comme exprimé précédemment, il me semble que les données globales sur l’empreinte environnementale du numérique, prises seules, perpétuent in fine les discours de dématérialisation et déterritorialisation. J’aimerais à titre d’exemple développer le cas des centres de données, que j’ai mentionné précédemment, comme étude de cas pour observer les défaillances de la vision globale et les enjeux de l'approche territoriale. 
</p>

<h3>Table des matières</h3>
<a href="#corriger">Corriger la vision globale</a><br/>
<a href="#completer">Compléter la vision globale</a><br/>
<a href="#myopie">Myopie globale</a><br/>
<a href="#vision">Vision territoriale</a><br/>
<a href="#approche">Que faire d’une approche territoriale</a><br/>
<a href="#perspectives">Perspectives</a><br/>
<br/>

<h3 id="corriger">Corriger la vision globale</h3>

<p>
    D’après les estimations de Masanet et al. et de l’IEA (<i>International Energy Agency</i>), les centres de données représenteraient 1% de la consommation globale d’électricité (205 TWh)<a href="#definition-1" aria-describedby="footnote-label" id="definition"></a>. Cette consommation serait plutôt stable (+6% depuis 2010) malgré une augmentation croissante de la puissance et de la charge de ces centres. 
</p>

<figure class="img-figure-xlarge"><div class="img-wrapper" style="padding-bottom: 35%"><img alt="" class="img" loading="lazy" srcset="https://gauthierroussilhe.com/img/blog-datacenter-01.svg"></div><figcaption>Estimation globale et projections de Masanet et al.</figcaption></figure>

<p>
    Ce prisme global permet de dire que les centres de données ne sont pas un sujet important dans l’étude de l’empreinte environnementale globale du numérique. Toutefois, les données ainsi présentées posent de nombreuses limites : <b>parler d’électricité ne revient à parler que de la phase d’usage des centres de données et de leur consommation électrique durant cette phase, cela n’est donc qu’une vue très réduite de l’empreinte globale</b>. Ensuite, les jeux de données permettant d’arriver à ces estimations globales sont largement influencés par les données des parcs de centres de données américains. Si l’on garde le prisme réducteur de la consommation d’électricité on observe alors d’autres tendances sur d’autres zones géographiques : la Commission Européenne a publié un rapport en mai 2020 annonçant que la consommation d’électricité annuelle des centres de données (<i>Data centers</i>, DC) en UE28 était passée de 53,9 TWh/a en 2010 à 76,8 TWh/a en 2018, soit 30% d’augmentation<a href="#ue-1" aria-describedby="footnote-label" id="ue-a"></a>. <b>La Commission Européenne estime que la consommation annuelle des DC représentait 2,7% de la consommation annuelle d’électricité en UE28 en 2018 et prévoit que cette consommation augmente de 21% d’ici 2025</b>. Une nouvelle fois, cette consommation n’est pas également répartie sur le territoire européen, 82% de la consommation d’électricité se situe en Europe de l’ouest et du nord. De même, les données asiatiques sur le sujet restent dures à obtenir et à confirmer. Par exemple, à Singapour le Ministère de l’Industrie et du Commerce estime que les 60 centres de données sur son territoire représentent <a href="https://www.channelnewsasia.com/news/business/new-data-centres-singapore-temporary-pause-climate-change-14719154" rel="noopener noreferrer">7% de la consommation d’électricité nationale en 2020</a> (3,8 TWh à peu près). En Chine, Greenpeace estime que la consommation électrique annuelle était de 161 TWh en 2018<a href="#greenpeace-1" aria-describedby="footnote-label" id="greenpeace-a"></a>, et prévoit une très forte augmentation.
</p>

<figure class="img-figure"><div class="img-wrapper" style="padding-bottom: 72%"><img alt="" class="img" loading="lazy" srcset="https://gauthierroussilhe.com/img/blog-datacenter-02.svg"></div><figcaption>Comparaisons des estimations entre Masanet et al. et Montevecchi et al., 2010 et 2018</figcaption></figure>

<p>
    On peut tout de suite voir apparaître des creux entre l’estimation globale de Masanet et al. et de l’IEA, et les chiffres reportés indépendamment dans chaque région. Pourquoi un tel écart ? Les estimations globales citées renvoient toujours à des données de consommation électrique des centres de données aux USA (Shehabi et al.<a href="#shehabi-1" aria-describedby="footnote-label" id="shehabi-a"></a>) et utilisent une méthode <i>bottom-up</i> (partir de la consommation unitaire d’un appareil puis multiplier par le nombre d’appareils). La consommation américaine s’est stabilisée grâce à des gains en efficacité, à de nouveaux matériels et à l’augmentation de la taille des centres de données (augmentation des <i>hyperscalers</i>) mais aussi parce que les méthodes de refroidissement ont changé, passant de la climatisation à des circuits d’eau froide (un transfert d’impact). De plus, les approches <i>bottom-up</i> amènent plutôt à des estimations basses (à l’inverse des approches <i>top-down</i>). Généralement, <b>les estimations basses proviennent d’études utilisant les jeux de données américains (Shehabi et al.), les estimations régionales utilisent d’autres sources, comme le Borderstep Institute pour les données européennes par exemple</b>. Du fait des données manquantes, les estimations globales seront toujours complexes à modéliser et il est donc préférable de regarder les estimations régionales qui utilisent des jeux de données plus contextualisés.
</p>

<h3 id="completer">Compléter la vision globale</h3>

<p>
    Jusqu'à présent nous n’avons fait que montrer les chiffres données par un prisme réducteur : phase d’usage et consommation d’électricité. Si nous voulons réellement avoir une meilleure idée de l’empreinte des centres de données nous devons alors rajouter les phases de fabrication et de fin de vie et d’autres facteurs environnementaux : consommation d’eau, consommation de ressources “abiotiques” (non vivantes), production de déchets, consommation d’énergie primaire, sans oublier les émissions de gaz à effet de serre liées à tout cela. Toutefois, nous devons faire face à un premier constat, ces données sont très rares et ne sont pas diffusées publiquement. <b>À ma connaissance il n’existe que quelques approches d’analyses de cycle de vie (ACV) publiées “récemment” et de façon ouverte : Whitehead et al. en 2015<a href="#whitehead-1" aria-describedby="footnote-label" id="whitehead-a"></a> et Shah et al. de 2009 à 2014<a href="#shah-1" aria-describedby="footnote-label" id="shah-a"></a></b>. Dans le secteur des centres de données, une publication de 2015 est relativement vieille car les méthodes d’installation, de fabrication et de gestion ont largement changé depuis. <b>Dans cette littérature scientifique, on estime que la phase de fabrication (construction du bâtiment + fabrication des équipements informatiques) représente en moyenne 15% de l’empreinte énergétique et GES d’un centre de données dans un pays à l’électricité “moyennement” carbonée ( env. 150-200gCO2/kWh)</b>. Pour arriver à ce chiffrage on estime que le bâtiment est neuf et durera 20 ans et que les équipements IT sont remplacés tous les 4 à 5 ans. À partir des scopes 3 des GAFAM, une publication récente de chercheurs de Facebook, Harvard et Arizona University<a href="#arizona-1" aria-describedby="footnote-label" id="arizona-a"></a> a estimé que l’impact carbone des centres de données liés aux équipements IT, à la construction et aux infrastructures était plus fort qu’imaginé. Il y aurait donc un intérêt croissant à mieux comprendre ces “oublis”.
</p>

<h4>Construction du bâtiment et des installations</h4>
<p>
    Généralement <b>l’intégration des impacts liés à la construction d’un centre de données sont optionnels</b> (<a href="https://www.etsi.org/deliver/etsi_es/203100_203199/203199/01.03.01_60/es_203199v010301p.pdf" rel="noopener noreferrer">Norme ETSI 203 199 V.1.3.1, p.39</a>) car considérés comme trop faibles, c’est-à-dire autour de 1%. Cependant, l’augmentation de la taille des centres de données et l’usage récurrent de béton et de métal implique que la construction ne devrait pas être sous-estimée. Cela est d’autant plus important car les projets de construction de centres de données se multiplient : Microsoft a annoncé qu’il veut <a href="https://www.crn.com/news/data-center/microsoft-will-build-up-to-100-new-data-centers-each-yearf" rel="noopener noreferrer">construire 50 à 100 nouveaux centres de données par an</a> jusqu’à une date indéterminée. Les projets de développement de Microsoft sont loin d’être une exception, les investissements s’accumulent dans le secteur : <a href="https://www.crn.com/news/data-center/covid-19-spurs-record-data-center-spending-by-amazon-google-microsoft" rel="noopener noreferrer">37 milliards de dollars ont été dépensés dans le secteur rien qu’au 3e trimestre 2020</a>. De même, la phase de construction peut avoir beaucoup plus d’impacts sur d’autres facteurs environnementaux comme les émissions de particules fines (PM-10) et les rejets toxiques. Finalement, l’achat de l’infrastructure énergétique et de refroidissement (HVAC, CRAV, générateurs, etc.) doit être regarder de près, surtout si leur durée de vie est plus faible que la moyenne.
</p>

<figure class="img-figure"><div class="img-wrapper" style="padding-bottom: 50%"><img alt="" class="img" loading="lazy" srcset="https://gauthierroussilhe.com/img/blog-datacenter-06.jpg"></div><figcaption>Construction d'un centre de données à Clarksville, Tennessee (Google)</figcaption></figure>

<h4>Fabrication des équipements IT</h4>
<p>
    Si la construction du bâtiment représente peu de l’empreinte énergétique totale, l’empreinte liée à la fabrication des ordinateurs, serveurs et autres équipements IT n’est pas à sous-estimer. <b>Elle représente généralement la majorité des impacts hors phase d’usage (sauf sur certains facteurs). Cette empreinte se situe autant sur la consommation d’eau (liée à l’extraction et traitement) que sur la consommation de ressources (métaux, etc.) et sur les autres polluants liés (arsenic, cadmium, etc.)</b>. Cette empreinte est aussi importante car le rythme de remplacement des équipements se situe généralement aux alentours des 4 à 5 ans, leur impact est donc “amorti” comptablement sur moins d’années. Les impacts environnementaux eux ne sont pas "amortis" et s'accumulent dans des régions bien précises. 
</p>

<h4>Fin de vie des installations</h4>
<p>
    La fin de vie des centres de données n’est pas pris en compte dans les analyses alors que cette phase peut être productice d’énormément de déchets. Décommissionner un centre de données, c’est démonter l’ensemble du parc, enlever l’infrastructure électrique, celle de refroidissement, enlever les dalles, etc. <b>À cela se rajoute le fait que la politique de redondance et de sécurité nécessite des équipements sans risques, donc on préfère remplacer plus tôt que prendre le risque de la panne</b>. Par exemple, des générateurs qui ont une durée de vie de 35 à 40 ans peuvent être <a href="https://www.datacenterdynamics.com/en/analysis/what-happens-mechanical-and-electrical-equipment-during-data-center-decommissioning/" rel="noopener noreferrer">décommissionné au bout de 15 ans</a> alors qu’ils n’ont quasiment jamais servi. La fin de vie de l’équipement IT doit aussi poser question au vu des durées de vie relativement faibles.
</p>

<h4>Consommation d’eau</h4>
<p>
    Si la consommation d’eau est importante lors de la phase de fabrication des équipements, il y a cependant un autre paramètre à prendre en compte : la génération d’électricité. Produire de l’électricité, via une turbine à vapeur par exemple, utilise de l’eau qui va être évaporé et va donc sauter une étape dans le cycle de l’eau. Les méthodes de génération d’électricité sont donc à prendre en compte pour comprendre l’empreinte hydrique des centres de données. Les États-Unis ont une intensité hydrique de 2,18 L/kWh, la France serait aux alentours de 4 L/kWh. La différence s’explique par la plus grande proportion d’énergie nucléaire et d'hydroélectrique en France. De plus, <b>la consommation d’eau liée au refroidissement des centres de données varie largement en fonction des circuits de récupération d’eau</b>. Il est important de se concentrer sur les prélèvements d’eau sur le réseau municipal pour avoir une idée claire du poids hydrique du refroidissement. Dans un article de 2016, l’Uptime Institute estimait qu’un centre de données de 1 MW consommait 25,5 millions de litres d’eau par an (25 500 m3)<a href="#uptime-1" aria-describedby="footnote-label" id="uptime-a"></a>. Dans un rapport de 2019 pour l’ADEME, Cécile Diguet et Fanny Lopez remontaient que, d’après un opérateur américain, un centre de données de 15 MW consommerait jusqu’à 1,6 millions de litres d’eau par jour (1 600 m3)<a href="#diguet-1" aria-describedby="footnote-label" id="diguet-a"></a>. Comme nous allons le voir plus tard les besoins en eau des nouveaux data centers posent de véritables problématiques territoriales.

</p>

<h4>Consommation d’électricité</h4>
<p>
    Si la focale est sur la consommation d’électricité des centres de données, il y a tout de même une subtilité à comprendre. Alors que la plupart des géants américains annoncent que leurs centres de données seront 100% énergies renouvelables, une grosse distinction est de mise sur ce 100% d’énergies renouvelables. <b>Il faut différencier deux approches pour calculer l’empreinte carbone de l’électricité : le <i>location-based</i> ou le <i>market-based</i>. Le <i>location-based</i> désigne l’intensité carbone de l’électricité physiquement consommée par le centre de données. Le <i>market-based</i> désigne l’intensité carbone de l’électricité après abattement comptable entre l’électricté consommée et l’électricité achetée via différentes mécanismes financiers</b>. Parmi ces différents mécanismes on trouve des <i>Renewable Energy Certificates</i> (RECs) qui sont généralement considérés de maigre qualité car ils ne peuvent pas prouver entièrement l’origine de l’électricité. De ce fait, les <i>Power Purchase Agreements</i> (PPAs) sont devenus plébiscités par les géants du numérique. Un PPA peut prendre plusieurs formes, il peut être direct : dans ce cas un acheteur s’engage sur plusieurs années auprès d’un producteur à acheter l’électricité physiquement fournie à ses installations. C’est le type de PPA à privilégier pour que les affirmations d’alimentation en énergies renouvelables soient crédibles. Mais il y a aussi des PPA “virtuels” ou “financiers” qui ne sont pas liés à la livraison physique d’électricité. Dans ce cas, un acheteur s’engage à investir dans la construction d’une centrale d’énergie renouvelable (solaire / vent) et d’acheter de l’électricité future à un certain tarif quand la centrale est en route. Toutefois, ces PPAs virtuels permettent de soustraire comptablement du carbone de leur bilan avant même que les centrales soient construites. Aujourd’hui les GAFAM sont les plus gros acheteurs du monde en PPAs (direct ou virtuel) et façon globale <a href="https://www.iea.org/commentaries/data-centres-and-energy-from-global-headlines-to-local-headaches" rel="noopener noreferrer">le secteur des TIC représente plus de la moitié des PPAs de 2009 à 2019</a>.
</p> 

<p>
    Google semble être le mieux placé pour obtenir ou faire advenir des PPAs directs. Cependant, les affirmations de neutralité carbone sur la plupart de ses centres de données sont liés à des RECs ou à des PPAs virtuels et cela est même visible dans les données fournies par Google. <b>Le géant américain annonce que son centre de données à Eemshaven aux Pays-bas serait 100% alimenté en EnR depuis son ouverture en 2016. Or, sur les matrices de fourniture d'électricité de Google on voit bien que 69% de l'alimentation électrique a été fournie par des EnR. Les 31% restants sont compensés par des RECs ou des PPA virtuels</b>. L'affirmation de Google en préambule n'est donc pas factuellement correcte.
</p>

<figure class="img-figure"><div class="img-wrapper" style="padding-bottom: 30%"><img alt="" class="img" loading="lazy" srcset="https://gauthierroussilhe.com/img/blog-datacenter-07.jpg"></div><figcaption>Affirmation d'alimentation en énergies renouvelables du centre de données Google à Eemshaven, aux Pays-bas</figcaption></figure>
<figure class="img-figure-large"><div class="img-wrapper" style="padding-bottom: 65%"><img alt="" class="img" loading="lazy" srcset="https://gauthierroussilhe.com/img/blog-datacenter-08.jpg"></div><figcaption>Descriptif de l'alimentation en électricité <i>location-based</i> du centre de données d'Eemshaven</figcaption></figure>

<h3 id="myopie">Myopie globale</h3>
<p>
    Ce bref résumé de tout ce qui n’est pas compté dans les estimations globales de l’empreinte des centres de données montre qu’il manque énormément de pièces au puzzle. L’absence de données ouvertes et partagées crée une myopie qui sera à terme de plus en plus insoutenable au fur et à mesure que des centaines de centres de données sont et seront construits chaque année. <b>En échangeant avec des spécialistes des analyses de cycle de vie dans le numérique, on arrive à peu près à la même hypothèse que la phase de fabrication (bâtiment + matériel) serait aux alentours de 12 à 15% de l’empreinte totale d’un centre de données (cela est toutefois variable en fonction du mix énergétique du pays)</b>. Cela veut dire que les opérateurs peuvent intégrer autant d’énergie renouvelable qu’ils le souhaitent dans leur consommation électrique, il y aura une part intense en impacts carbone, eau, ressources liés à la construction/fabrication qu’ils pourront difficilement compresser. L’énergie utilisée dans une mine, dans le fret, dans la chaine d’approvisionnement et de production a beaucoup moins de chances d’être renouvelable et de se décarboner. De même, il est essentiel de rappeler tous les autres facteurs environnementaux qui sont complètement oubliés : biodiversité (!), particules fines, écotoxicité, … <b>Finalement, la consommation d’électricité augmente, qu’elle soit renouvelable ou non, pourtant un des objectifs prioritaires de la transition est de réduire notre consommation énergétique et notre empreinte matérielle</b>. D’une part, le problème est que la demande d’électricité très concentrée des centres de données est bloquante pour les territoires dans lesquels ils sont installées. D’autre part, <b>le recours aux énergies renouvelables pour décarboner une consommation croissante augmente drastiquement l’empreinte matérielle de tout le secteur</b>. Les énergies renouvelables populaires comme l’éolien et le solaire ont une empreinte matérielle conséquente et requièrent de nombreuses métaux. L’usage des énergies renouvelables est bien plus pertinent dans le cadre d’une décrue énergétique, pas l’inverse. Auquel cas on ne fera que décarboner la croissance énergétique mais on ne fait pas évoluer la base de nos systèmes énergétiques.
</p>

<figure class="img-figure"><div class="img-wrapper" style="padding-bottom: 105%"><img alt="" class="img" loading="lazy" srcset="https://gauthierroussilhe.com/img/blog-datacenter-03.svg"></div><figcaption>Résumé de toutes les informations manquantes pour mieux évoluer l'empreinte environnementale du secteur des centres de données</figcaption></figure>

<p>
    En conclusion préliminaire, cette myopie sur l’électricité et le carbone permet de mettre sous un beau jour le secteur des centres de données. Le jour où on ajoutera au bilan carbone, le bilan d’empreinte eau et le bilan d’empreinte matérielle alors les transferts d’impacts et de pollution seront bel et bien visibles. Encore une fois, nous devons intégrer d’autres facteurs : où sont la biodiversité, les particules fines, l’écotoxicité pour les humains et les milieux ? <b>Le carbone n’est qu’une partie du problème et nous ne pourrons pas cacher éternellement les transferts d’impacts. Cette myopie est d’autant plus flagrante au vu du rythme de construction des centres de données dans les années à venir</b>.
</p>

<h3 id="vision">Vision territoriale</h3>
<p>
    Comme montré précédemment la vision globale est aujourd’hui largement incomplète et continue à possiblement perpétuer une vision dématérialisée du secteur numérique. Face à ce constat, ma méthode de recherche a changé pour partir du territoire où se situe mon objet d’étude. Ce faisant, <b>je m’intéresse bien plus aux conditions matérielles du secteur, c’est-à-dire les pré-requis de matières et de flux pour qu’une installation soit construite, déployée et fonctionne</b>. J’avais déjà posé les prémices de ce retournement dans l’article de Sciences du design co-écrit avec Nicolas Nova. Notre proposition tenait à étudier le numérique à travers trois centres concentriques : matérialisation, territorialisation, terrestrialisation. Je m’attache aujourd’hui à poursuivre cette voie via certains travaux en cours comme, par exemple, <a href="http://gauthierroussilhe.com/post/chip-water-taiwan.html" rel="noopener noreferrer">la fabrication des semi-conducteurs à Taiwan et l’approvisionnement en eau</a>. La présente analyse s’inscrit aussi dans cette voie de recherche, d’autant plus que le cas des centres de données est exemplaire pour ce genre de démarches.
</p>

<figure class="img-figure-large"><div class="img-wrapper" style="padding-bottom: 60%"><img alt="" class="img" loading="lazy" srcset="https://gauthierroussilhe.com/img/blog-datacenter-04.svg"></div><figcaption>Cadre d'analyse des "numériques situés"</figcaption></figure>

<h4>Construire et faire fonctionner un centre de données sur un territoire</h4>
<p>
    Quels sont les facteurs qui influencent la localisation d’un centre de données ? Pour résumer : <b>l’accès privilégié au réseau électrique (poste source) et au réseau fibre d’internet (dorsale ou backbone) ; des risques naturels faibles (éruptions, inondations, etc.) ; l’accès à un foncier peu cher ; de l’électricité à bas prix ou à tarif privilégié ; et potentiellement l’accès à un réseau d’eau</b>. Quand un opérateur décide de s’installer dans la ville X parce qu’elle répond à ces critères alors il va traditionnellement faire une demande de permis de construire, des études préalables sur les différents points demandés (environnement, risques industriels, etc.), des demandes de travaux civils pour le câblage, une demande de réservation de puissance électrique, un demande d'approvisionnement en eau si nécessaire, et ce ne sont que quelques éléments parmi bien d’autres. Un centre de données va mettre en moyenne 2 ans à se construire ou à rénover un bâtiment existant. Les grands opérateurs de centres de données (Equinix, Interxion, GAFAM, etc.) sont généralement bien reçus par les collectivités car ils véhiculent un discours de progrès et d’innovation, amènent des retombées fiscales plus ou moins conséquentes pour la collectivité, et des promesses d’emplois plus ou moins appuyées.
</p>

<figure class="img-figure-xxlarge"><div class="img-wrapper" style="padding-bottom: 62%"><img alt="" class="img" loading="lazy" srcset="https://gauthierroussilhe.com/img/blog-datacenter-05.jpg"></div><figcaption>Résumé des enjeux territoriaux d'un centre de données d'après la thèse de Clément Marquet, "Binaire Béton : comment les infrastructures numériques aménagent la ville"</figcaption></figure>

<h4>La réservation de puissance électrique</h4>
<p>
    Dans la ville X, même si l’arrivée de l’opérateur du centre de données est bien accueillie une première difficulté peut possiblement apparaitre : l’électricité réservée au distributeur. Le réseau électrique est dispatché dans les villes parce ce qu’on appelle des postes sources gérés par le distributeur. En France, Enedis gère cette distribution jusqu’à un certain seuil, RTE s’assure de l’acheminement des très hauts voltages et des grandes demandes de puissances. Un poste source dispose d’une puissance à distribuer (en kVA ou MW) qu’il faut répartir entre résidentiel, tertiaire, industriel, transport, etc. <b>Une industrie va réserver une puissance correspondante à son pic de production et possiblement au développement futur de sa chaine de production. Les opérateurs de centres de données font de même mais dans des ordres de grandeur surprenant par rapport à leur opérations</b>. La réservation de puissance et la consommation étant opaques, il est très dur de comprendre pourquoi les opérateurs réservent autant : soit ils souhaitent occuper le terrain pour éviter une potentielle concurrence électrique, soit cela est lié à des développements futurs très importants. De plus, les opérateurs de centres de données réservent la même puissance sur deux postes sources différents afin d’avoir une ligne de secours si l’un des deux postes sources subit une panne. <b>Lorsque les réservations de puissance amènent les postes sources à bout de leur puissance disponible, le distributeur d’électricité contacte la collectivité pour l’informer de la situation, amenant parfois à la construction d’un nouveau poste source (pour plusieurs millions d’euros et en comptant 10 ans de travaux avant mise en service)</b>.
</p>

<p>
    Ces conflits d’usage autour de l’électricité ont déjà posé de nombreux problèmes dans les collectivités à Plaine Commune en Seine-Saint-Denis, à Marseille, à Dublin, Francfort et Amsterdam, Stockholm, Helsinski pour ne citer que quelques exemples européens. Par exemple, en 2013, la mairie de Marseille, ayant oublié de réserver la puissance électrique pour une nouvelle ligne de tramway, a du négocier avec un opérateur (Interxion) pour libérer 6 MW de réservation. À Plaine Commune, Clément Marquet a très bien documenté les conflits locaux liés aux centres de données et notamment ceux liés à la réservation de puissance, de la consommation d’électricité croissante et de son inadéquation avec les plans locaux de transition énergétique<a href="#marquet-1" aria-describedby="footnote-label" id="marquet-a"></a>. <b>Le déploiement de nouveaux centres de données toujours plus grands (hyperscalers) met en défaut les schémas de distribution électrique de la plupart des  villes qui leur accueillent. À ce titre, les trois hubs européens, <a href="https://www.datacenterdynamics.com/en/news/bill-banning-new-data-center-developments-introduced-in-ireland/" rel="noopener noreferrer">Dublin</a>, <a href="https://www.datacenterdynamics.com/en/news/frankfurt-to-regulate-data-centers/" rel="noopener noreferrer">Francfort</a> et <a href="https://www.datacenterdynamics.com/en/news/amsterdam-pauses-data-center-building/" rel="noopener noreferrer">Amsterdam</a>, ont ordonné ces dernières années l’arrêt de tout nouveau déploiement pendant un an, le temps pour ces villes de repenser leur approvisionnement électrique</b>. En 2020, les centres de données représentaient 11% de la consommation d’électricité en Irlande et, <a href="https://www.eirgridgroup.com/site-files/library/EirGrid/All-Island-Generation-Capacity-Statement-2020-2029.pdf" rel="noopener noreferrer">d’après le distributeur national EirGrid</a>, cette consommation atteindra 27% en 2029 au rythme actuel. Celui-ci soulève aussi le fait que les centres de données pourraient absorder la capacité d’énergie renouvelable sur le réseau ralentissant la transition énergétique du pays. Les moratoires s’accumulent plus ou moins pour les mêmes raisons aux Pays-bas ou à <a href="https://www.datacenterdynamics.com/en/analysis/cracking-green-conundrum-singapore-amid-data-center-moratorium/" rel="noopener noreferrer">Singapour</a>. Par le prisme territorial on peut voir à quel point la consommation d’électricité des centres de données peut être concentrée et poser des véritables problématiques d’aménagement et de planification pour les collectivités. À ce titre, chaque équipe municipale devrait être particulièrement attentive lorsqu’elle sera approchée par un opérateur de centres de données.
</p>

<h4>La consommation d’eau</h4>
<p>
    Les opérateurs de centres de données qui misent sur un mode de refroidissement à circuit d’eau froide doivent prélever de l’eau soit dans le réseau d’eau municipal, soit par prélèvement direct dans une nappe souterraine s’ils disposent de leur propre station de pompage. De quel ordre est le prélèvement d’eau d’un centre de données ? Comme dit précédemment, cela dépend de la localisation du centre et du climat. Un centre de données de taille moyenne en Californie consommerait jusqu’à 1 600 m3 par jour. Une partie de cette eau est évaporée et donc ne poursuit donc pas son cycle habituellement, c’est pour cela qu’on dit qu’elle est consommée. Toutefois, <b>différents types d’eau peuvent être utiliser – potable, non-potable, eaux de rejet – et surtout l’eau peut être recyclée pour être utilisée plusieurs fois dans le circuit, ce processus peut porter plusieurs termes – réclamation, recyclage, conservation</b>. 
</p>

<p>
    Pour bien comprendre le prélèvement réel en eau il faut donc regarder les demandes d’approvisionnement en eau fait à la collectivité. Par exemple, à Red Oak, Texas, <a href="https://time.com/5814276/google-data-centers-water" rel="noopener noreferrer">Google demandait 5,5 milliards de litres d’eau à l’année</a> pour un de ces centres de données, soit presque 10% de la consommation annuelle du <i>county</i>. À Mesa, Arizona, un projet centre de données géant, supposément pour Facebook, a fait  <a href="https://www.datacenterdynamics.com/en/news/huge-data-center-moves-forward-in-mesa-despite-arizona-water-concerns/" rel="noopener noreferrer">une demande initiale de 6,4 millions de litres d’eau par jour</a>, soit 681 millions de litres par an et et 1,9 milliard par an dans la 3e phase de son développement. Dans la même ville, de nombreux centres de données sont déjà présents, et <b>Google est actuellement en train de construire un centre qui utilisera 3,8 à 15 millions de litres d’eau par jour. La plupart de l’eau provient du fleuve Colorado dont le niveau descend et dont les ressources ont été sur-allouées <a href="https://morrisoninstitute.asu.edu/sites/default/files/the_myth_of_safe-yield_0.pdf" rel="noopener noreferrer">d’après un rapport de l’Université d’Arizona</a></b>. Cependant, la possible insoutenabilité du nouveau projet de centre de données a fait peu de poids face à un projet de 800 millions de dollars avec différentes retombées financières pour la collectivité, le projet de construction a donc été voté à 6 contre 1 au conseil municipal. Le gestionnaire de l’eau de Mesa rapportait que la ville avait consommé 105 milliards de litres d’eau en 2019 et estime pouvoir atteindre (et supporter) 227 milliards en 2040. Cette estimation semble bien optimiste au vu des réserves d’eau dans l’État. 
</p>

<figure class="img-figure"><div class="img-wrapper" style="padding-bottom: 70%"><img alt="" class="img" loading="lazy" srcset="https://gauthierroussilhe.com/img/blog-datacenter-09.jpg"></div><figcaption>Système de refroidissement liquide du centre de données d'Apple à Mesa (Tom Tingle / The Republic)</figcaption></figure>

<p>
    Une question reste en suspens, pourquoi mettre des centres de données dans des zones désertiques, et généralement en zone de stress hydrique ? Il semblerait qu’il soit plus facile d’évacuer la chaleur dans un climat sec ; mais aussi les déserts sont des zones peu exposés aux risques naturels (tremblements de terre, etc.) ; la possibilité d’avoir de l’énergie solaire abondante ; et un accès à de l’électricité et de l’eau à un prix faible, notamment pour l’eau dans les États américains mentionnés. Il est tout de même dur de comprendre la stratégie à long terme de ce genre d’installations face à des possibles difficultés d’approvisionnement en eau ou une élévation des prix de l’électricité ou de l’eau, ou tout simplement quand le stress hydrique s’accentue rapidement comme en période de sécheresse, ce qui se passe actuellement dans l’ouest américain.
</p>

<h3 id="approche">Que faire d’une approche territoriale</h3>
<p>
    Il m’est impossible de lister un à un tous les facteurs environnementaux à prendre en compte au niveau territorial mais je renvoie à l’excellent rapport de Cécile Diguet et Fanny Lopez pour l’ADEME : “L’impact spatial et énergétique des data centers sur les territoires” et à la note récente de Lopez “Data centers: Anticipating and planning digital storage”<a href="#diguet-2" aria-describedby="footnote-label" id="diguet-b"></a>. On pourrait parler de l’occupation des sols liée aux hyperscalers qui vont au-delà des 10 000 m2. Rien qu’à Francfort les centres de données occupent 640 000 m2 et 270 000 m2 sont en projet. C’est ce type de développement agressif qui a poussé Francfort à un moratoire pour réguler le secteur (en plus de la consommation électrique et du manque d’intérêt à récupérer la chaleur fatale). <b>L’infrastructure numérique, notamment celle liée aux GAFAM et opérateurs géants, doit être planifier et réguler par les collectivités mais elle a, jusqu’à présent, bénéficié de nombreux passe-droits</b>. Un opérateur de centres de données ne pourra pas toujours obtenir le terrain, l’électricité et l’eau qu’il souhaite, il devra s’adapter aux contraintes territoriales dont il ne souhaite pas s’occuper. Pour cela, les collectivités doivent être préparées et disposer d’outils. L’obligation de l’ouverture et la centralisation des données de consommation foncière, électrique et hydrique des centres de données seraient un grand pas en avant pour planifier et réguler tout nouveau développement. À ce titre, il me semble que l’approche territoriale permettrait, si les données sont disponibles, de modifier le régime d’exception dont le secteur a bénéficié jusque là.
</p>

<p>
    Au niveau environnemental, l’approche territoriale permet de sortir de la mystique des valeurs relatives d’efficacité pour aligner une consommation en valeur absolue à un stock local et à un milieu précis. <b>Un des points faibles dans l’aménagement des centres de données est qu’ils ne peuvent pas être complètement délocalisés, ils doivent être proche de leur “audience”. Ainsi, les impacts environnementaux restent visibles auprès des utilisateurs finaux et peuvent être combattus ou atténués directement soit par la mobilisation citoyenne, soit par l’action légale du territoire ou état concerné</b>. Finalement, l’approche territoriale montre, qu’au délà des discours dans les rapports RSE, l’infrastructure peut directement rentrer en collision avec l’objectifs de transition écologique des territoires où elle s’implante. S’il s’agit d’un jeu à somme nulle, alors l’embellissement environnemental relatif (et surtout comptable) des grands opérateurs se paye au prix de la dégradation des plans de transition locaux. 
</p>

<h4>Combiner les approches</h4>
<p>
    Nous allons devoir continuer à suivre au mieux possible l’évolution au niveau mondial, mais je ne pense pas que cette approche puisse continuer à vivre seule ou alors elle deviendra potentiellement contre-productive. L’approche territoriale est déjà supportée par de nombreux acteurs et donc être méthodologiquement accentuée pour devenir un standard dans le rapport des données environnementales du numérique. Il ne me semble pas qu’on puisse avancer sur la question environnementale sans intégrer géographie, cartographie, sciences humaines et sociales, études de terrain locales, en somme, faire entrer le qualitatif et des périmètres restreints. <b>La prochaine pièce du puzzle méthodologique sera la connexion entre vision globale et territoriale dans un secteur qui est à la fois concentré et dilué</b>. De nombreuses années de recherche seront nécessaires pour avancer sur cette question.
</p>

<h3 id="perspectives">Perspectives</h3>
<p>
    En 2020, <a href="https://www.datacenterdynamics.com/en/news/hyperscale-operator-building-reaches-150-billion-in-a-year-synergy/" rel="noopener noreferrer">150 milliards de dollars ont été investi par les géants du cloud</a>, dont la moitié pour construire des nouveaux centres de données. Les plus gros investissements sont dans l’ordre : Amazon, Microsoft, Google, Facebook, Apple, Alibaba et Tencent. <b>S’il y avait 541 hyperscalers dans le monde en juin 2020, Synergy Research Group estime maintenant qu’il y en aurait 625 aujourd'hui. Comment tous ces nouveaux centres sont installés, quel a été l’impact de leur construction, de la fabrication du matériel, quelles sont leurs demandes locales en électricité et en eau, quels sont les conflits d’usage liés à cela, est-ce que ces développements sont compatibles avec un monde à +2°C ?</b> Quid des réseaux de télécommunication et des équipements utilisateurs ? Nous n'avons ici qu’effleuré la question environnementale sur un des trois tiers techniques et comme vous le voyez, cette question est loin d’être résolue.
</p>

<p>
    Au fur et à mesure que les conditions matérielles pour la construction et le fonctionnement de l’infrastructure vont devenir difficilement soutenables, les GAFAM et autres géants vont sûrement développer leur propre infrastructure énergétique et hydrique. Certains d’entre eux s'occupent déjà de la conception de leur propre équipement IT. <b>Cette verticalisation aura le grand défaut d’invisibiliser les consommations réelles de ces infrastructures</b>. Nous pouvons aujourd’hui encore récupérer quelques données des distributeurs d’eau et d’énergie mais lorsqu’Amazon construira ses propres postes sources, <a href="https://www.datacenterdynamics.com/en/news/silicon-valley-power-to-build-60kv-substation-for-amazon-web-services-data-center-in-santa-clara/" rel="noopener noreferrer">comme à Santa Clara</a>, ou Google ses propres stations de pompage alors la boite noire continuera de grossir. Nous comprendrons alors de moins en moins bien l’empreinte environnementale réelle de ces géants autant au niveau global que territorial. Cet effort d’opacification sera supporté par les méthodes de publication des données et de comptabilité qui permettent aujourd’hui de cacher une partie de l’empreinte et ses nombreux transferts d’impacts.
</p>


<div class="footnotes">
    <header class="list-header">
    <h2 class="visually-hidden" id="footnote-label">Notes de bas de page</h2>
    </header>
    <ol>
        <li id="definition-1">
            Masanet et al., "Recalibrating global data center energy-use estimates", Science, 28 février 2020 ; IEA, "Data Centres and Data Transmission Networks", juin 2020 <a href="#definition" aria-label="Back to content">↩</a>
        </li>
        <li id="ue-1">
            Montevecchi et al., "Energy-efficient Cloud Computing Technologies and Policies for an Eco-friendly Cloud Market – Final Study Report", European Commission, 2020 <a href="#ue-a" aria-label="Back to content">↩</a>
        </li>
        <li id="greenpeace-1">
            Greenpeace East Asia, "Powering the Cloud: How China’s Internet Industry Can Shift to Renewable Energy”, Greenpeace East Asia et the North China Electric Power University, 2019 <a href="#greenpeace-a" aria-label="Back to content">↩</a>
        </li>
        <li id="shehabi-1">
            Shehabi et al.,“United States data center energy usage report”, Lawrence Berkeley National Laboratory, 2016 <a href="#shehabi-a" aria-label="Back to content">↩</a>
        </li>

        <li id="whitehead-1">
            Whitehead et al., "Assessing the environmental impact of data centres part 1: Background, energy use and metrics", Building and Environment 82, 2014 ; Whitehead et al., "Assessing the environmental impact of data centres part 2: Building environmental assessment methods and life cycle assessment", Building and Environment 93, 2015 <a href="#whitehead-a" aria-label="Back to content">↩</a>
        </li>
        <li id="shah-1">
            Shah et al., "Sources of Variability in Data Center Lifecycle Assessment", 2012 IEEE International Symposium on Sustainable Systems and Technology, 2012 <a href="#shah-a" aria-label="Back to content">↩</a>
        </li>
        <li id="arizona-1">
            Gupta et al., "Chasing Carbon: The Elusive Environmental Footprint of Computing", IEEE International Symposium on High-Performance Computer Architecture, 2021 <a href="#arizona-a" aria-label="Back to content">↩</a>
        </li>
        <li id="uptime-1">
            Heslin, “Ignore Data Center Water Consumption at Your Own Peril", Uptime Institute, 2016 <a href="#uptime-a" aria-label="Back to content">↩</a>
        </li>
        <li id="diguet-1">
            Diguet et Lopez, "L’impact spatial et énergétique des data centers sur les territoires", ADEME, 2019 <a href="#diguet-a" aria-label="Back to content">↩</a>
        </li>
        <li id="marquet-1">
            Marquet, "Binaire Béton : quand les infrastructures numériques aménagent la ville", 2019 <a href="#marquet-a" aria-label="Back to content">↩</a>
        </li>
        <li id="diguet-2">
            Lopez et al., "Data centers: Anticipating and planning digital storage", Institut Paris Région, 2021<a href="#diguet-b" aria-label="Back to content">↩</a>
        </li>
    </ol>
</div>
