title: Technical Mentorship Reimagined: Time-bound and No Awkward Asks Necessary
url: https://shopify.engineering/technical-mentorship-reimagined
hash_url: 7b8d925b24ca7a4777becd5cc212d11a

<p>Struggling with a concept and frantically trying to find the answers online? Are you thinking: <em>I should just ping a teammate or Is this something I should already know? That’s fine, I’ll ask anyway. </em>And then you do ask and get an answer and are feeling pretty darn proud of yourself and move forward. <em>But wait, now I have about 25 follow-up questions. </em>Sound familiar?</p>
<p>Or how about the career growth questions that can be sometimes too uncomfortable asking your lead or manager? <em>Oh, I know, I’ll take them to reddit. But wait, they have no company context. </em>Yeah, also familiar. <em>I know. I should get a mentor! But darn. I’ve heard so many stories… Who do I approach? Will they be interested? What if they reject me? And what if it’s not working out?</em></p>
<p>Shopify is a collaborative place. We traditionally <a href="https://shopify.engineering/pair-programming-explained" target="_blank" title="Pair Programming Explained - Shopify Engineering" rel="nofollow noopener noreferrer">pair with other developers</a> and conduct code reviews to level up. This approach is great for just-in-time feedback and unblocking us on immediate problems. We wanted to continue this trend and also look at how we can support developers in growing themselves through longer term conversations.</p>
<p>We surveyed our developers at Shopify and learned that they:</p>
<ul>
<li>Love to learn from others at Shopify</li>
<li>Are busy people and find it challenging to make dedicated time for learning</li>
<li>Want to grow in their technical and leadership skills.</li>
</ul>
<p>These findings birthed the idea of building a mentorship program targeted at solving these exact problems.<strong> Enter Shopify’s Engineering Mentorship Program. </strong>Shopify’s RnD Learning Team partnered with developers across the company to design a unique mentorship program and this guide walks readers through the structure, components, value-adds, and lessons we’ve had over the past year.</p>
<h1>Gathering Participants</h1>
<p>Once a quarter developers get an email inviting them to join the upcoming cycle of the program and sign up to be a mentee, mentor, or both. In addition to the email that is sent out, updates are posted in a few prominent Slack channels to remind folks that the signup window for the upcoming cycle is now open.</p>
<p>When signing up to participate in the program, mentees are asked to select their areas of interest and mentors are asked to select their areas of expertise. The current selections include:</p>
<ul>
<li>Back-end</li>
<li>Data</li>
<li>Datastores</li>
<li>Front-end</li>
<li>Infrastructure</li>
<li>Mobile - Android</li>
<li>Mobile - iOS</li>
<li>Mobile - React Native</li>
<li>Non-technical (leadership, management).</li>
</ul>
<p>Mentors are also prompted to choose if they are interested in supporting one or two mentees for the current cycle.</p>
<h1>Matching Mentors and Mentees</h1>
<p>Once the signup period wraps up, we run an automated matching script to pair mentees and mentors. Pairs are matched based on a few criteria:</p>
<ul>
<li>Mentor isn’t mentee's current lead</li>
<li>Mentor and mentee don’t report to same lead</li>
<li>Aligned areas of interest and expertise based on selections in sign-up forms</li>
<li>Mentee job level is less than or equal to mentor job level.</li>
</ul>
<p>The matching system intentionally avoids matching based upon criteria such as geographic location or department to broaden the developer’s network and gain company context they would have otherwise not been exposed to.</p>
<p>Pairs are notified by email of their match and invited to a kickoff meeting where organizers welcome participants, explain the program model and value that they will receive as a mentor or mentee, and answer any questions.</p>
<h1>Running the Six Week Program Cycle</h1>
<p>Each program cycle runs for six weeks and pairs are expected to meet for approximately one hour per week.</p>
<figure><img alt="Shopify’s Engineering Mentorship Program overview" data-src="https://cdn.shopify.com/s/files/1/0779/4361/files/Shopify_Engineering_Mentorship_Program_overview.jpg?v=1612976625" class="lazyload">
<figcaption>Shopify’s Engineering Mentorship Program overview</figcaption>
</figure>
<p>The time bound nature of the program enables developers to try out the program and see if it’s a good fit for them. They can connect with someone new and still feel comfortable knowing that they can walk away, no strings attached.</p>
<p>The voluntary signup process ensures that developers who sign up to be a mentor are committed to supporting a mentee for the six week duration and mentees can rest assured that their mentor is keen on supporting them with their professional growth. The sign-up emails as well as the sign-up form reiterate the importance of only signing up as a mentor or mentee if you can dedicate at minimum an hour per week for the six week cycle.</p>
<h2>Setting Goals</h2>
<p>In advance of the first meeting, mentees are asked to identify technical skills gaps they want to improve. During their first meeting, mentees and mentors work together building a tangible goal that they can work towards over the course of the six weeks. Goals often change and that’s expected.</p>
<p>Through the initial kickoff meeting and weekly check-ins via Slack, we reinforce and reiterate throughout the program that the goal itself is never the goal, but an opportunity to work towards a moving target.</p>
<p>Defining the goal is often the most challenging part for mentees. Mentors take an active role in supporting them craft this—the program team also provides tons of real examples from past mentees.</p>
<h2>Staying Connected as a Group</h2>
<p>Outside of the one on one weekly meetings between each pairing of mentor and mentee, the broader mentorship community stays connected on Slack. Two Slack channels are used to manage the program and connect participants with one another and with the program team.</p>
<p>The first Slack channel is a public space for all participants as well as anyone at the company who is curious about the program. This channel serves the purpose to advertise the program and keep participants connected to each other as well as to the program team. This is done by regularly asking questions and continuously sharing their experiences of what’s working well, how they’ve pivoted (or not) from their initial goals, and any general tips to support fellow mentors and mentees throughout the program.</p>
<p>The second Slack channel is a private space that is used exclusively by the program team and mentors. This channel is a space for mentors to be vulnerable and lean on fellow mentors for suggestions and resources.</p>
<h2>Preparing the Participants with a Guidebook</h2>
<p>Beyond the Slack channels, the other primary resource our participants use is a mentorship guidebook that curates tips and resources for added structure. The program team felt that a guidebook was an important aspect to include for participants who were craving more support. While it is entirely an optional resource to use, many first time mentors and mentees find it to be a helpful tool in navigating an otherwise open ended relationship between themselves and their match. It includes tips on sample agendas for your first meeting, example goals, and ways to support your mentee. For example, invite them to one of your meetings and debrief afterwards, pair, or do a code review.</p>
<h1>Growing Mentor’s Skills Too</h1>
<p>Naturally teaching someone else a technical concept helps reinforce it in our own minds. Our mentors constantly share how they’ve found the program helps refine their craft skills as well:</p>
<p><em>“Taking a step back from my day-to-day work to meet with [them] and chatting about career goals at a higher level, gave me more insight into what I personally want from my career path as well.”</em></p>
<p>The ability to mentor others in their technical acumen and craft is a skill that’s valued at Shopify. As engineers progress in their career here, being an effective mentor becomes a bigger piece of what’s expected in the role. The program gives folks a place to improve both their mentorship and leadership skills through iteration.</p>
<p>Throughout the program, mentors receive tips and resources from engineering leaders at the company that are curated by the program team and shared via Slack, but the most valuable piece ends up being the support they provide each other through a closed channel dedicated to mentors.</p>
<p>Here’s an actual example of how mentors help unblock each other:</p>
<div>
<p><strong>Mentor 1</strong>: <em>Hey! Im curious to know how y’all are supporting your mentees in coming up with a measurable goal? My mentee’s original goal was “learn how Shopify core works” and we’ve scoped that down to “learn how jobs are run in core” but we still don’t have it being something that’s measurable and can clearly be ticked off by the end of the 6 weeks. They aren’t the most receptive to refining the goal so I’m curious how any of you have approached that as well?</em></p>
</div>
<div>
<p><strong>Mentor 2</strong>: <em>Hmmm, I’d try to get to the “why” when they say they want to learn how Shopify core works. Is it so they can find things easier? Make better decisions by having more context? Are they interested in why it’s structured the way it is to inform them on future architecture decisions? Maybe that could help in finding something they can measure. Or if they’re just curious, could the goal be something like being able to explain to someone new to Shopify what the different components of the system are and how they interact? Or they’re able to create a new job in core in x amount of time?</em></p>
</div>
<div>
<p><strong>Mentor 3</strong>: <em>If you've learned how something works, you should be able to tell someone else. So I turn these learning goals into a goal to write a wiki page or report, make a presentation, or teach someone else one on one.</em></p>
</div>
<div>
<p><strong>Mentor 1</strong>: <em>Thanks for all the replies! I surfaced adapting the learning goal to have an outcome so they've decided on building an example that can be used as documentation and shared with their team. They're writing this example in the component their team maintains as well which will help in "learn how Shopify works" as they weren't currently familiar with the component</em>.</p>
</div>
<h1>Gathering Program Feedback</h1>
<p>At the end of the six weeks mentees and mentors are asked to provide constructive feedback to one another and the program officially comes to a close. </p>
<p>Program participants receive a feedback survey that helps organizers understand what’s working well and what to revise for future cycles. Participants share</p>
<ul>
<li>Whether they would recommend the program to someone else or not</li>
<li>What the best part of the program was for them</li>
<li>What they would like to see improved for future cycles.</li>
</ul>
<p>Tweaks are made within a short month or so and the next cycle begins. A new opportunity to connect with someone else, grow your skills, and do it in a time-bound and supportive environment.</p>
<h1>What We’ve Learned in 2020</h1>
<p>Overall, it’s been working well. The type of feedback we receive from participants is definitely share-worthy:</p>
<p><em>“was phenomenal to learn more about Production Engineering and our infrastructure. Answered hundreds of mind-numbing questions with extreme patience and detail; he put in so much time to write and share resources—and we wrapped up with a live exercise too! I always look forward to our sessions and it was like walking into a different, fantasy-like universe each time. Hands down the best mentoring experience of my professional career thus far.” </em>- Senior Developer</p>
<ul>
<li>We’ve had 300+ developers participate as mentees and 200+ as mentors.</li>
<li>98% of survey respondents indicated that they would recommend the program to someone else.</li>
<li>The demand is there. Each cycle of the program we have to turn away potential mentees because we can’t meet the demand due to limited mentors. We are working on strategies to attract more mentors to better support the program in 2021.</li>
</ul>
<p>The themes that emerged in terms of where participants found the most value are around:</p>
<ul>
<li>
<strong>Building relationships</strong>: getting to know people is hard. Getting to know colleagues in a fully remote world is near impossible. This program helps.</li>
<li>
<strong>Having dedicated time for learning set aside each week:</strong> we’ve all got a lot to do. We know that making time for learning is important, but it can easily fall on the back burner. This program helps with that too.</li>
<li>
<strong>Developing technical craft skills</strong>: growing your technical chops? Say no more.</li>
<li>
<strong>Developing skills as a teacher and mentor</strong>: getting better at supporting peers can be tricky. You need experience and a safe space to learn with real people.</li>
<li>
<strong>Gaining broader Shopify context:</strong> being a T-shaped developer is an asset. By T-shaped we are referring to the vertical bar of the “T” as the areas the developer is an expert in, while the horizontal bar refers to areas where the developer has some breadth and less depth of knowledge. Getting outside of our silos and learning about how different parts of Shopify work helps build stronger developers and a stronger team.</li>
</ul>
<p>Reinvesting in the developers at Shopify is one way that we help individuals grow in their careers and increase the effectiveness of our teams.</p>
<p>Some great resources that inspired us:</p>

<div class="marketing-block marketing-block--light marketing-block--padded">
<p><a href="https://www.linkedin.com/in/naqsar/" target="_blank" title="Sarah Naqvi on LinkedIn" rel="nofollow noopener noreferrer">Sarah is a Senior Program Manager</a> who manages Engineering learning programs at Shopify. For the past five years, she has been working on areas such as designing and building the initial version of the Dev Degree program to now designing and delivering the Engineering Mentorship Program. She is focused on helping our engineers develop their professional skills and creating a strong Engineering community at Shopify.</p>
</div>

<hr>
<p>We're planning to DOUBLE our engineering team in 2021 by hiring 2,021 new technical roles (see what we did there?). Our platform handled record-breaking sales over BFCM and commerce isn't slowing down. <a href="https://www.shopify.com/careers/2021?itcat=EngBlog&amp;itterm=Post" target="_blank">Help us scale &amp; make commerce better for everyone</a>.</p>
